﻿using System;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.SimulationCore {
  [StorableClass]
  public sealed class ModelTimeUpdateAction<TModel> : Action<TModel> where TModel : IModel {
    public static readonly Guid Id = new Guid("1dd664ec-809d-494b-a96b-567696a59a5b");
    public override Guid ActionId {
      get { return Id; }
    }

    public double NextTime { get; private set; }

    [StorableConstructor]
    private ModelTimeUpdateAction(bool deserializing) : base(deserializing) { }
    private ModelTimeUpdateAction(Action<TModel> original, Cloner cloner) : base(original, cloner) { }
    public ModelTimeUpdateAction(IActivity<TModel> mandate, double nextTime)
      : base(mandate) {
      NextTime = nextTime;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ModelTimeUpdateAction<TModel>(this, cloner);
    }

    public override void Execute(TModel model) {
      model.CurrentTime = NextTime;
    }
  }
}
